package com.ruoyi.web.controller.place;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.place.TdPlace;
import com.ruoyi.web.controller.manager.TdPlaceManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.ruoyi.web.controller.place
 *
 * @author wangxy
 * @version JDK 8
 * @className TdPlaceController
 * @date 2024/8/13
 * @description 涉密场所变更
 */
@Controller
@RequestMapping("/system/placeChange")
public class TdPlaceChangeController extends BaseController {


    private String prefix = "system/placeChange";

    @Resource
    private TdPlaceManager placeManager;


    @RequiresPermissions("system:placeChange:view")
    @GetMapping()
    public String place() {
        return prefix + "/placeChange";
    }

    /**
     * 场所列表
     */
    @RequiresPermissions("system:placeChange:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdPlace tdPlace) {
        startPage();
        List<TdPlace> tdPlaces = placeManager.selectTdPlaceChangeList(tdPlace);
        return getDataTable(tdPlaces);
    }


    /**
     * 涉密场所变更
     */
    @RequiresPermissions("system:placeChange:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") String id, ModelMap mmap) {
        TdPlace tdPlace = placeManager.selectTdPlace(id);
        mmap.put("tdPlace", tdPlace);
        return prefix + "/edit";
    }

    /**
     * 涉密场所变更
     */
    @RequiresPermissions("system:placeChange:edit")
    @Log(title = "涉密场所变更", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TdPlace tdPlace) {
        return toAjax(placeManager.updateChange(tdPlace));
    }

    /**
     * 详情场所
     */
    @RequiresPermissions("system:placeChange:detail")
    @GetMapping("/detail/{id}")
    public String detail(@PathVariable("id") String id, ModelMap mmap) {
        TdPlace tdPlace = placeManager.selectTdPlace(id);
        mmap.put("tdPlace", tdPlace);
        return prefix + "/detail";
    }


}
