package com.ruoyi.web.controller.system.check;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.check.TdCheckReport;
import com.ruoyi.system.domain.check.dto.TdCheckReportDTO;
import com.ruoyi.web.controller.manager.CheckReportManager;
import com.ruoyi.web.controller.manager.SysAreaManager;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * packageName com.ruoyi.web.controller.system.check
 *
 * @author wangxy
 * @version JDK 8
 * @className CheckReportController
 * @date 2024/8/15
 * @description 检查报告
 */
@Controller
@RequestMapping("/system/checkReport")
public class CheckReportController extends BaseController {


    private String prefix = "system/checkReport";

    @Resource
    private CheckReportManager checkReportManager;

    @Resource
    private SysAreaManager sysAreaManager;

    @RequiresPermissions("system:check:view")
    @GetMapping()
    public String checkReport() {
        return prefix + "/checkReport";
    }

    /**
     * 检查报告列表
     */
    @RequiresPermissions("system:check:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdCheckReport tdCheckReport) {
        startPage();
        List<TdCheckReport> tdCheckReports = checkReportManager.selectTdCheckReportList(tdCheckReport);
        return getDataTable(tdCheckReports);
    }

    /**
     * 导出检查报告管理列表
     */
    @RequiresPermissions("system:check:export")
    @Log(title = "检查报告", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TdCheckReport tdCheckReport) {
        List<TdCheckReport> tdCheckReports = checkReportManager.selectTdCheckReportList(tdCheckReport);
        tdCheckReports.forEach(tdCheck1 -> {
            tdCheck1.setFramework(sysAreaManager.getAreaName(tdCheck1.getFramework()));
            tdCheck1.setArea(sysAreaManager.getAreaName(tdCheck1.getArea()));
        });
        ExcelUtil<TdCheckReport> util = new ExcelUtil<>(TdCheckReport.class);
        return util.exportExcel(tdCheckReports, "检查报告管理数据");
    }

    /**
     * 新增检查报告
     */
    @GetMapping("/add")
    public String add(ModelMap mmap) {
        mmap.put("user", getSysUser());
        return prefix + "/add";
    }

    /**
     * 新增检查报告
     */
    @RequiresPermissions("system:check:add")
    @Log(title = "检查报告", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(@RequestBody TdCheckReportDTO checkReportDTO) {
        return toAjax(checkReportManager.saveOrUpdate(checkReportDTO));
    }

    /**
     * 修改检查报告
     */
    @RequiresPermissions("system:check:edit")
    @GetMapping("/edit/{checkId}")
    public String edit(@PathVariable("checkId") String checkId, ModelMap mmap) {
        TdCheckReportDTO tdCheckReportDTO = checkReportManager.getTdCheckReportDTO(checkId);
        mmap.put("tdCheckReportDTO", tdCheckReportDTO);
        return prefix + "/edit";
    }


    /**
     * 修改检查报告
     */
    @RequiresPermissions("system:check:edit")
    @Log(title = "检查报告", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(@RequestBody TdCheckReportDTO checkReportDTO) {
        return toAjax(checkReportManager.saveOrUpdate(checkReportDTO));
    }


    /**
     * 详情
     */
    @RequiresPermissions("system:check:detail")
    @GetMapping("/detail/{checkId}")
    public String detail(@PathVariable("checkId") String checkId, ModelMap mmap) {
        TdCheckReportDTO tdCheckReportDTO = checkReportManager.getTdCheckReportDTO(checkId);
        mmap.put("tdCheckReportDTO", tdCheckReportDTO);
        return prefix + "/detail";
    }


    /**
     * 详情
     */
    @GetMapping("/view/{checkId}")
    @ResponseBody
    public AjaxResult view(@PathVariable("checkId") String checkId) {
        return AjaxResult.success(checkReportManager.getTdCheckReportDTO(checkId));
    }


    /**
     * 删除
     */
    @RequiresPermissions("system:check:remove")
    @Log(title = "检查报告", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids) {
        return toAjax(checkReportManager.deletedTdCheckReportIds(ids));
    }


    /**
     * 自查
     */
    @RequiresPermissions("system:check:selfCheck")
    @GetMapping("/selfCheck/{checkId}")
    public String selfCheck(@PathVariable("checkId") String checkId, ModelMap mmap) {
        TdCheckReportDTO tdCheckReportDTO = checkReportManager.getTdCheckReportDTO(checkId);
        mmap.put("tdCheckReportDTO", tdCheckReportDTO);
        return prefix + "/selfcheck";
    }


    /**
     * 保存自查结果
     */
    @RequiresPermissions("system:check:selfCheck")
    @Log(title = "检查报告管理", businessType = BusinessType.CHECK)
    @PostMapping("/selfCheckSave")
    @ResponseBody
    public AjaxResult selfCheckSave(@RequestBody TdCheckReportDTO checkReportDTO) {
        checkReportDTO.setCheckState("2");
        return toAjax(checkReportManager.saveOrUpdate(checkReportDTO));
    }

    /**
     * 打印操作
     */
    @RequiresPermissions("system:check:print")
    @GetMapping("/checkprint/{checkId}")
    public String checkPrint(@PathVariable("checkId") String checkId, ModelMap mmap) {
        TdCheckReportDTO tdCheckReportDTO = checkReportManager.getTdCheckReportDTO(checkId);
        mmap.put("tdCheckReportDTO", tdCheckReportDTO);
        return prefix + "/checkprint";
    }


}
