package com.ruoyi.web.controller.system.count;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.system.domain.TdPropertyInfo;
import com.ruoyi.system.domain.check.TdCheckReport;
import com.ruoyi.system.domain.count.CheckResultCountDTO;
import com.ruoyi.system.domain.count.CheckTypeCountDTO;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.service.ITdNotifyService;
import com.ruoyi.system.service.check.TdCheckReportService;
import io.swagger.annotations.ApiOperation;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;

/**
 * 涉密检查统计
 */
@Controller
@RequestMapping("/system/checknum")
public class TdChecknumController extends BaseController{
    private String prefix = "system/check/checknum";

    @Resource
    private TdCheckReportService checkReportService;

    @Autowired
    private ITdNotifyService tdNotifyService;

    @RequiresPermissions("system:checknum:view")
    @GetMapping()
    public String checknum() {
        return prefix + "/checknum";
    }

    @ApiOperation("检查通知统计")
    @PostMapping("/countNotifyList")
    @ResponseBody
    public AjaxResult countNotifyList() {
        return AjaxResult.success(tdNotifyService.selectCountNotifyList());
    }

    private List<String> checkResult = Arrays.asList("通过", "未通过","待检查","已保存");

    private List<String> checkType = Arrays.asList("自行检查", "保密局检查");

    /**
     *
     *  检查结果统计
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/countResult")
    @ResponseBody
    public AjaxResult countbf() {
        CheckResultCountDTO checkResultCountDTO = checkReportService.selectResultCount();
        List<JSONObject> datas = checkResult.stream()
                .map(name -> {
                    AtomicReference<Object> value = new AtomicReference<>(0L);
                    if("通过".equals(name)){
                        value.set(checkResultCountDTO.getTg());
                    }else if("未通过".equals(name)){
                        value.set(checkResultCountDTO.getWtg());
                    }else if("待检查".equals(name)){
                        value.set(checkResultCountDTO.getDjc());
                    }else{
                        value.set(checkResultCountDTO.getYbc());
                    }
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("value", value.get());
                    jsonObject.put("name", name);
                    return jsonObject;
                })
                .collect(Collectors.toList());
        return AjaxResult.success(datas);
    }
    /**
     *
     *  检查类型统计
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/countType")
    @ResponseBody
    public AjaxResult countXH() {
        CheckTypeCountDTO checkTypeCountDTO = checkReportService.selectTypeCount();
        List<JSONObject> datas = checkType.stream()
                .map(name -> {
                    AtomicReference<Object> value = new AtomicReference<>(0L);
                    if("自行检查".equals(name)){
                        value.set(checkTypeCountDTO.getZxjc());
                    }else{
                        value.set(checkTypeCountDTO.getBmjjc());
                    }
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("value", value.get());
                    jsonObject.put("name", name);
                    return jsonObject;
                })
                .collect(Collectors.toList());
        return AjaxResult.success(datas);
    }

    @Autowired
    private ISysDictDataService dictDataService;

    /**
     *
     *检查类型统计
     * @return
     */
    @PostMapping("/countCheckType")
    @ResponseBody
    public AjaxResult countCheckType() {
        SysDictData sysDictData =  new SysDictData();
        sysDictData.setDictType("sys_check_type");
        List<SysDictData> smType = dictDataService.selectDictDataList(sysDictData);
        List<String> list = smType.stream().map(SysDictData::getDictLabel).collect(Collectors.toList());
        List<Long> yAxisData = new ArrayList<>();
        smType.forEach(xAxis -> {
            AtomicReference<Long> yAxis = new AtomicReference<>(0L);
            Integer count = checkReportService.lambdaQuery()
                    .eq(TdCheckReport::getCheckType, xAxis.getDictValue())
                    .count();
            if(Objects.isNull(count)){
                count = 0;
            }
            yAxis.set(Long.valueOf(count));
            yAxisData.add(yAxis.get());
        });
        JSONObject obj = new JSONObject();
        obj.put("xAxisData", list.toArray());
        obj.put("yAxisData", yAxisData);
        return AjaxResult.success(obj);
    }










}
